# =============================================================================
# -------------------------- example R code - Part I --------------------------
# 
# "Sparse Bayesian modelling of underreported count data" 
# (by Dvorzak, M. and Wagner, H.)
#
# The R code is based on the R package "pogit" (available on CRAN):  
#
#           http://cran.r-project.org/web/packages/pogit/index.html 
# =============================================================================

library(pogit)
# see package?pogit for the package description


# --------------------------------------------------------------
# Section 4.1: --- Simulation I (example simulated data set) ---
# --------------------------------------------------------------

# load simulated data set 'simul1'
data(simul1)
# see ?simul1 for a description of the simulated data set

# or alternatively, read data (electronic supplement)
# simul1 <- read.table("simul1.txt", header = TRUE)

y <- simul1$y
E <- simul1$E
X <- as.matrix(simul1[, -c(1, 2, 8, 9)]) # W = X
validation <- simul1[, c("m", "v"), drop = FALSE]


# function call:
m1 <- pogitBvs(y = y, E = E, X = X, validation = validation, 
               mcmc = list(M = 10000, burnin = 4000, thin = 5, startsel = 2000))

# print and summarize results
print(m1)
summary(m1)

# show traceplots of the MCMC draws
plot(m1)

# show autocorrelation plots of the MCMC draws
plot(m1, type = "acf", lag.max = 50)

# show posterior means for risks and reporting probabilities 
# (compare to Figure 2a/b)
res <- summary(m1, printRes = TRUE)$resTable
probs <- t(res$probs)
risks <- res$risks

par(las = 1, mfrow = c(1,2), mar = c(4,3,1,2)+1.4, mgp = c(3,1,0))
plot(1:length(risks), risks, type = "l", ylim = c(0, 4.5), xlab = "", 
     ylab = expression(paste("Risk ", lambda), sep=""), xaxt = "n")
axis(side = 1, at = 1:length(risks), line = 0.1, label = c(1:16))
plot(1:length(probs), probs, type = "l", ylim = c(0, 1), xlab = "", 
     ylab = expression(paste("Reporting probabilty ", p), sep = ""), 
     xaxt = "n")
axis(side = 1, at = 1:length(probs), line = 0.1, label = c(1:16))



# ---------------------------------------------------------------
# Section 4.2: --- Simulation II (example simulated data set) ---
# ---------------------------------------------------------------

# load simulated data set 'simul2'
data(simul2)
# see ?simul2 for a description of the simulated data set

# or alternatively, read data (electronic supplement)
# simul2 <- read.table("simul2.txt", header = TRUE)

y <- simul2$y
E <- simul2$E
cID <- simul2$cID
X <- as.matrix(simul2[, -c(1:3, 9, 10)])
validation <- simul2[, c("v", "m"), drop = FALSE]


# NOTE (!): long run-time
# function call (with random intercept in both sub-models)
model <- list(riBeta = 1, riAlpha = 1, clBetaID = cID, clAlphaID = cID)
m2 <- pogitBvs(y = y, E = E, X = X, validation = validation, model = model, 
               mcmc = list(M = 30000, burnin = 10000, startsel = 5000, thin = 10), 
               BVS = TRUE)

# print and summarize results
print(m2)
summary(m2)

# show traceplots of the MCMC draws
plot(m2)

# show autocorrelation plots of the MCMC draws
plot(m2, type = "acf", lag.max = 50)
